@@ -213,7 +213,8 @@ static gboolean    window_find_entry_key_pressed_cb (GtkWidget       *widget,
 						     gpointer         data);
 static void        window_find_save_settings      (YelpWindow        *window);
 static void        window_find_buttons_set_sensitive (YelpWindow      *window,
-						      gboolean        sensitive);
+						      gboolean        prev,
+						      gboolean        next);
 static void        window_find_clicked_cb         (GtkWidget         *button,
 						   YelpWindow        *window);
 static void        window_find_next_cb            (GtkAction *action, 
@@ -934,7 +935,7 @@ window_do_load (YelpWindow  *window,
 	window_error (window, error, TRUE);
     }
 
-    window_find_buttons_set_sensitive (window, TRUE);    
+    window_find_buttons_set_sensitive (window, TRUE, TRUE);    
 }
 
 /******************************************************************************/
@@ -992,7 +993,21 @@ search_activated (GtkAction *action,
 
     search_terms = gtk_entry_action_get_text (GTK_ENTRY_ACTION (action));
 
-    uri = encode_search_uri (search_terms);
+    /* Do some basic checking here - if someones looking for a man
+     * or info page, save doing the search and just bring them directly to
+     * the relevant page
+     * Trigger it using "man:<foo>", "man <foo>" or "info:<foo>"
+     */
+    if (g_str_has_prefix (search_terms, "man:") || 
+	g_str_has_prefix (search_terms, "info:")) {
+	uri = g_strdup (search_terms);
+    } else if (g_str_has_prefix (search_terms, "man ") && 
+	       !strstr (&(search_terms[4])," ")) {
+	uri = g_strdup (search_terms);
+	uri[3]=':';
+    } else {
+	uri = encode_search_uri (search_terms);
+    }
 
     yelp_window_load (window, uri);
 
@@ -2647,12 +2662,32 @@ window_copy_mail_cb (GtkAction *action, YelpWindow *window)
 static void
 window_help_contents_cb (GtkAction *action, YelpWindow *window)
 {
-    /* Since we are already running, and are calling ourselves,
-     * we can make this function easy by just creating a new window
-     * and avoiding calling gnome_help_display_desktop
-     */
-    g_signal_emit (window, signals[NEW_WINDOW_REQUESTED], 0, 
-                   "ghelp:user-guide#yelp");
+    GnomeProgram *program = gnome_program_get ();
+    GError *error = NULL;
+
+    g_return_if_fail (YELP_IS_WINDOW (window));
+
+    gnome_help_display_desktop (program, "user-guide", 
+                                "user-guide", "yelp", &error);
+
+    if (error) {
+	GtkWidget *dialog;
+
+	dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+ 	                                 0,
+	                                 GTK_MESSAGE_ERROR,
+	                                 GTK_BUTTONS_CLOSE,
+	                                 _("Could not display help for Yelp.\n"
+	                                 "%s"),
+	                                 error->message);
+
+	g_signal_connect_swapped (dialog, "response",
+	                          G_CALLBACK (gtk_widget_destroy),
+	                          dialog);
+	gtk_widget_show (dialog);
+
+	g_error_free (error);
+    }
 }
 
 static void
@@ -2759,14 +2794,9 @@ window_find_previous_cb (GtkAction *action, YelpWindow *window)
 
     priv = window->priv;
     if (!window_find_again (window, FALSE)) {
-	gtk_widget_set_sensitive (GTK_WIDGET (priv->find_next), TRUE);
-	gtk_widget_set_sensitive (GTK_WIDGET (priv->find_prev), FALSE);
-	g_object_set (G_OBJECT (priv->find_next_menu), "sensitive", TRUE, 
-		      NULL);
-	g_object_set (G_OBJECT (priv->find_prev_menu), "sensitive", FALSE, 
-		      NULL);
+	window_find_buttons_set_sensitive (window, FALSE, TRUE);
     } else {
-	window_find_buttons_set_sensitive (window, TRUE);
+	window_find_buttons_set_sensitive (window, TRUE, TRUE);
     }
 }
 
@@ -2777,14 +2807,9 @@ window_find_next_cb (GtkAction *action, YelpWindow *window)
 
     priv = window->priv;
     if (!window_find_again (window, TRUE)) {
-	gtk_widget_set_sensitive (GTK_WIDGET (priv->find_next), FALSE);
-	gtk_widget_set_sensitive (GTK_WIDGET (priv->find_prev), TRUE);
-	g_object_set (G_OBJECT (priv->find_next_menu), "sensitive", FALSE, 
-		      NULL);
-	g_object_set (G_OBJECT (priv->find_prev_menu), "sensitive", TRUE, 
-		      NULL);
+	window_find_buttons_set_sensitive (window, TRUE, FALSE);
     } else {
-	window_find_buttons_set_sensitive (window, TRUE);
+	window_find_buttons_set_sensitive (window, TRUE, TRUE);
     }
 }
 
@@ -2800,26 +2825,16 @@ window_find_clicked_cb (GtkWidget  *widget,
 
     if (GTK_TOOL_ITEM (widget) == priv->find_next) {
 	if (!window_find_again (window, TRUE)) {
-	    gtk_widget_set_sensitive (GTK_WIDGET (priv->find_next), FALSE);
-	    gtk_widget_set_sensitive (GTK_WIDGET (priv->find_prev), TRUE);
-	    g_object_set (G_OBJECT (priv->find_next_menu), "sensitive", FALSE, 
-			  NULL);
-	    g_object_set (G_OBJECT (priv->find_prev_menu), "sensitive", TRUE, 
-			  NULL);
+	    window_find_buttons_set_sensitive (window, TRUE, FALSE);
 	} else {
-	    window_find_buttons_set_sensitive (window, TRUE);
+	    window_find_buttons_set_sensitive (window, TRUE, TRUE);
 	}
     }
     else if (GTK_TOOL_ITEM (widget) == priv->find_prev) {
 	if (!window_find_again (window, FALSE)) {
-	    gtk_widget_set_sensitive (GTK_WIDGET (priv->find_next), TRUE);
-	    gtk_widget_set_sensitive (GTK_WIDGET (priv->find_prev), FALSE);
-	    g_object_set (G_OBJECT (priv->find_next_menu), "sensitive", TRUE, 
-			  NULL);
-	    g_object_set (G_OBJECT (priv->find_prev_menu), "sensitive", FALSE, 
-			  NULL);
+	    window_find_buttons_set_sensitive (window, FALSE, TRUE);
 	} else {
-	    window_find_buttons_set_sensitive (window, TRUE);
+	    window_find_buttons_set_sensitive (window, TRUE, TRUE);
 	}
     }
     else
@@ -2845,17 +2860,12 @@ window_find_entry_changed_cb (GtkEditable *editable,
     found = window_find_action (window);
 
     if (text == NULL || text[0] == '\0')
-	window_find_buttons_set_sensitive (window, FALSE);
+	window_find_buttons_set_sensitive (window, FALSE, FALSE);
     else
 	if (found) {
-	    gtk_widget_set_sensitive (GTK_WIDGET (priv->find_next), TRUE);
-	    gtk_widget_set_sensitive (GTK_WIDGET (priv->find_prev), FALSE);
-	    g_object_set (G_OBJECT (priv->find_next_menu), "sensitive", TRUE, 
-			  NULL);
-	    g_object_set (G_OBJECT (priv->find_prev_menu), "sensitive", FALSE, 
-			  NULL);
+	    window_find_buttons_set_sensitive (window, FALSE, TRUE);
 	} else {
-	    window_find_buttons_set_sensitive (window, TRUE);
+	    window_find_buttons_set_sensitive (window, TRUE, TRUE);
 	}
  
     g_free (text);
@@ -2873,18 +2883,11 @@ window_find_entry_activate_cb (GtkEditable *editable,
     window = YELP_WINDOW (data);
     priv = window->priv;
 
-    window_find_buttons_set_sensitive (window, FALSE);
-
     /* search forward and update the buttons */
     if (!window_find_again (window, TRUE)) {
-	gtk_widget_set_sensitive (GTK_WIDGET (priv->find_next), FALSE);
-	gtk_widget_set_sensitive (GTK_WIDGET (priv->find_prev), TRUE);
-	g_object_set (G_OBJECT (priv->find_next_menu), "sensitive", FALSE, 
-		      NULL);
-	g_object_set (G_OBJECT (priv->find_prev_menu), "sensitive", TRUE, 
-		      NULL);
+	window_find_buttons_set_sensitive (window, TRUE, FALSE);
     } else {
-	window_find_buttons_set_sensitive (window, TRUE);
+	window_find_buttons_set_sensitive (window, TRUE, TRUE);
     }
 }
 
@@ -2914,17 +2917,17 @@ window_find_entry_key_pressed_cb (GtkWidget    *widget,
 
 static void
 window_find_buttons_set_sensitive (YelpWindow  *window,
-				   gboolean    sensitive)
+				   gboolean    prev, gboolean next)
 {
     YelpWindowPriv *priv;
 
     priv = window->priv;
 
-    gtk_widget_set_sensitive (GTK_WIDGET (priv->find_next), sensitive);
-    gtk_widget_set_sensitive (GTK_WIDGET (priv->find_prev), sensitive);
-    g_object_set (G_OBJECT (priv->find_next_menu), "sensitive", sensitive, 
+    gtk_widget_set_sensitive (GTK_WIDGET (priv->find_next), next);
+    gtk_widget_set_sensitive (GTK_WIDGET (priv->find_prev), prev);
+    g_object_set (G_OBJECT (priv->find_next_menu), "sensitive", next, 
 		  NULL);
-    g_object_set (G_OBJECT (priv->find_prev_menu), "sensitive", sensitive, 
+    g_object_set (G_OBJECT (priv->find_prev_menu), "sensitive", prev, 
 		  NULL);
 }
 
